# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.1.4] - 11.01.2026

### Added

- `[dev]` extra that installs dev requirements

### Removed

- `requirements.txt` and `docs/requirements.txt`

## [1.1.3] - 22.12.2025

### Changed

- Update formatting and docs settings

### Fixed

- Small change to make dynamic versioning work after the package rename

## [1.1.2] - 10.11.2025

_Fix package version._


## [1.1.1] - 10.11.2025

_Fix package version._

## [1.1.0] - 04.11.2025

### Added

- `ruff` formatting with `pre-commit`
- CHANGELOG

### Changed

- Changed package name from `pelican-hep` to `pelican-lite` (also on `pypi`)

## [1.0.3] - 18.10.2025

### Added

### Changed

- Change default activation from `gelu` to `leaky_relu`
- Communicate clearly that `num_graphs` is required in `forward()` when `compile=True`

## [1.0.2] - 15.10.2025

### Changed

- Allow `edge_index` without self-loops
- Small fixes in README and docs

## [1.0.1] - 13.10.2025

_Fix package version._

## [1.0.0] - 13.10.2025

_First release._
